@@ -337,28 +337,28 @@ class FargateJobExecutor(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="region")
     def region(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "region"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="taskDefinitionArn")
     def task_definition_arn(self) -> builtins.str:
         '''task definition arn.'''
         return typing.cast(builtins.str, jsii.get(self, "taskDefinitionArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cluster")
     def cluster(self) -> typing.Optional[aws_cdk.aws_ecs.ICluster]:
         return typing.cast(typing.Optional[aws_cdk.aws_ecs.ICluster], jsii.get(self, "cluster"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="securityGroup")
     def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.ISecurityGroup], jsii.get(self, "securityGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="subnet")
     def subnet(self) -> typing.Optional[aws_cdk.aws_ec2.ISubnet]:
         return typing.cast(typing.Optional[aws_cdk.aws_ec2.ISubnet], jsii.get(self, "subnet"))
@@ -507,7 +507,7 @@ class FargateRunner(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
@@ -803,7 +803,7 @@ class JobExecutorImage(
 ):
     '''The docker image for the job executor.'''
 
-    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @jsii.member(jsii_name="of")
     @builtins.classmethod
     def of(cls, image: builtins.str) -> "JobExecutorImage":
         '''Custom image.
@@ -815,7 +815,7 @@ class JobExecutorImage(
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
         return typing.cast("JobExecutorImage", jsii.sinvoke(cls, "of", [image]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="DEBIAN")
     def DEBIAN(cls) -> "JobExecutorImage":
         '''Debian.
@@ -824,7 +824,7 @@ class JobExecutorImage(
         '''
         return typing.cast("JobExecutorImage", jsii.sget(cls, "DEBIAN"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="JSII")
     def JSII(cls) -> "JobExecutorImage":
         '''JSII for AWS CDK.
@@ -833,7 +833,7 @@ class JobExecutorImage(
         '''
         return typing.cast("JobExecutorImage", jsii.sget(cls, "JSII"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="NODE")
     def NODE(cls) -> "JobExecutorImage":
         '''Node.
@@ -842,7 +842,7 @@ class JobExecutorImage(
         '''
         return typing.cast("JobExecutorImage", jsii.sget(cls, "NODE"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="uri")
     def uri(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "uri"))
@@ -851,7 +851,7 @@ class JobExecutorImage(
 class JobRunnerImage(metaclass=jsii.JSIIMeta, jsii_type="cdk-gitlab.JobRunnerImage"):
     '''The docker image for the job runner.'''
 
-    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @jsii.member(jsii_name="of")
     @builtins.classmethod
     def of(cls, image: builtins.str) -> "JobRunnerImage":
         '''Custom image.
@@ -863,7 +863,7 @@ class JobRunnerImage(metaclass=jsii.JSIIMeta, jsii_type="cdk-gitlab.JobRunnerIma
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
         return typing.cast("JobRunnerImage", jsii.sinvoke(cls, "of", [image]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="DEFAULT")
     def DEFAULT(cls) -> "JobRunnerImage":
         '''Debian.
@@ -872,7 +872,7 @@ class JobRunnerImage(metaclass=jsii.JSIIMeta, jsii_type="cdk-gitlab.JobRunnerIma
         '''
         return typing.cast("JobRunnerImage", jsii.sget(cls, "DEFAULT"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="uri")
     def uri(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "uri"))
@@ -993,12 +993,12 @@ class Provider(
     def create_security_group(self) -> aws_cdk.aws_ec2.SecurityGroup:
         return typing.cast(aws_cdk.aws_ec2.SecurityGroup, jsii.invoke(self, "createSecurityGroup", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="gitlabEksRole")
     def gitlab_eks_role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
         return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], jsii.get(self, "gitlabEksRole"))
